netapp_ontap.resources.application_template API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.resources.application_template`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationTemplate (*args, **kwargs)`

  Application templates

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves application templates.

    ### Query examples

    The most useful queries on this API allows searches by name or protocol access. The following query returns all templates that are used to provision an Oracle application.

        GET /application/templates?name=ora*

    Similarly, the following query returns all templates that support SAN access.

        GET /application/templates?protocol=san

    ### Learn more

    - `DOC /application`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves application templates.

    ### Query examples

    The most useful queries on this API allows searches by name or protocol access. The following query returns all templates that are used to provision an Oracle application.

        GET /application/templates?name=ora*

    Similarly, the following query returns all templates that support SAN access.

        GET /application/templates?protocol=san

    ### Learn more

    - `DOC /application`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves application templates.

    ### Query examples

    The most useful queries on this API allows searches by name or protocol access. The following query returns all templates that are used to provision an Oracle application.

        GET /application/templates?name=ora*

    Similarly, the following query returns all templates that support SAN access.

        GET /application/templates?protocol=san

    ### Learn more

    - `DOC /application`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves an application template.

    ### Template properties

    Each application template has a set of properties. These properties are always nested under a property with the same name as the template. For example, when using the `mongo_db_on_san` template, the properties are found nested inside the `mongo_db_on_san` property. The properties nested under the template property are all specific to the template. The model for the application template object includes all the available templates, but only the object that corresponds to the template's name is returned, and only one is provided in any application API.
    The model of each template includes a description of each property and its allowed values or usage. Default values are also indicated when available. The template properties returned by this API include an example value for each property.

    ### Template prerequisites

    Each template has a set of prerequisites required for its use. If any of these prerequisites are not met, the `missing_prerequisites` property indicates which prerequisite is missing.

    ### Learn more

    - `DOC /application`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class ApplicationTemplateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationTemplate object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `description GET`

    Description.

  `links GET`

    The links field of the application_template.

  `maxdata_on_san GET POST PATCH`

    The maxdata_on_san field of the application_template.

  `missing_prerequisites GET`

    Missing prerequisites.

  `mongo_db_on_san GET POST PATCH`

    The mongo_db_on_san field of the application_template.

  `name GET`

    Template name.

  `nas GET POST PATCH`

    The nas field of the application_template.

  `nvme GET POST PATCH`

    The nvme field of the application_template.

  `oracle_on_nfs GET POST PATCH`

    The oracle_on_nfs field of the application_template.

  `oracle_on_san GET POST PATCH`

    The oracle_on_san field of the application_template.

  `oracle_rac_on_nfs GET POST PATCH`

    The oracle_rac_on_nfs field of the application_template.

  `oracle_rac_on_san GET POST PATCH`

    The oracle_rac_on_san field of the application_template.

  `protocol GET`

    Access protocol.

    Valid choices:

    - nas
    - nvme
    - s3
    - san
  `s3_bucket GET POST PATCH`

    The s3_bucket field of the application_template.

  `san GET POST PATCH`

    The san field of the application_template.

  `sql_on_san GET POST PATCH`

    The sql_on_san field of the application_template.

  `sql_on_smb GET POST PATCH`

    The sql_on_smb field of the application_template.

  `vdi_on_nas GET POST PATCH`

    The vdi_on_nas field of the application_template.

  `vdi_on_san GET POST PATCH`

    The vdi_on_san field of the application_template.

  `vsi_on_nas GET POST PATCH`

    The vsi_on_nas field of the application_template.

  `vsi_on_san GET POST PATCH`

    The vsi_on_san field of the application_template.